@@ -20,19 +20,14 @@
 #ifndef MACRO_H_
 #define MACRO_H_
 
-#define HEX_PRINT(X,Y)                \
-  {                                   \
-    int zz;                           \
-    for(zz = 0; zz < Y; zz++)         \
-      fprintf(stderr, "%02X", X[zz]); \
-    fprintf(stderr, "\n");            \
-  }
+#include <stdlib.h>  /* free() */
+
 #define MKINT_BE16(X) ( (X)[0] << 8 | (X)[1] )
 #define MKINT_BE24(X) ( (X)[0] << 16 | (X)[1] << 8 | (X)[2] )
 #define MKINT_BE32(X) ( (X)[0] << 24 | (X)[1] << 16 |  (X)[2] << 8 | (X)[3] )
 #define MKINT_BE48(X) ( (uint64_t)((X)[0]) << 40 | (uint64_t)((X)[1]) << 32 | (uint64_t)((X)[2]) << 24 | \
                         (uint64_t)((X)[3]) << 16 | (uint64_t)((X)[4]) << 8  | (uint64_t)((X)[5]) )
 
-#define X_FREE(X) do { if (X) free(X); X = NULL; } while(0)
+#define X_FREE(X)     ( free(X), X = NULL )
 
 #endif /* MACRO_H_ */
